==> zio-aws-kinesisanalyticsv2_2.13-5.17.115.1-sources.jar: zio/aws/kinesisanalyticsv2/model/KinesisStreamsOutputDescription.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.{RoleARN, ResourceARN}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class KinesisStreamsOutputDescription(
    resourceARN: ResourceARN,
    roleARN: Option[RoleARN] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.KinesisStreamsOutputDescription = {
    import KinesisStreamsOutputDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.KinesisStreamsOutputDescription
      .builder()
      .resourceARN(ResourceARN.unwrap(resourceARN): java.lang.String)
      .optionallyWith(
        roleARN.map(value => RoleARN.unwrap(value): java.lang.String)
      )(_.roleARN)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription
      .wrap(buildAwsValue())
}
object KinesisStreamsOutputDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.KinesisStreamsOutputDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription =
      zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription(
        resourceARN,
        roleARN.map(value => value)
      )
    def resourceARN: ResourceARN
    def roleARN: Option[RoleARN]
    def getResourceARN: ZIO[Any, Nothing, ResourceARN] =
      ZIO.succeed(resourceARN)
    def getRoleARN: ZIO[Any, AwsError, RoleARN] =
      AwsError.unwrapOptionField("roleARN", roleARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.KinesisStreamsOutputDescription
  ) extends zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription.ReadOnly {
    override val resourceARN: ResourceARN =
      zio.aws.kinesisanalyticsv2.model.primitives
        .ResourceARN(impl.resourceARN())
    override val roleARN: Option[RoleARN] = scala
      .Option(impl.roleARN())
      .map(value => zio.aws.kinesisanalyticsv2.model.primitives.RoleARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.KinesisStreamsOutputDescription
  ): zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kinesisanalyticsv2_2.13-5.19.12.1-sources.jar: zio/aws/kinesisanalyticsv2/model/KinesisStreamsOutputDescription.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.{RoleARN, ResourceARN}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class KinesisStreamsOutputDescription(
    resourceARN: ResourceARN,
    roleARN: Optional[RoleARN] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.KinesisStreamsOutputDescription = {
    import KinesisStreamsOutputDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.KinesisStreamsOutputDescription
      .builder()
      .resourceARN(ResourceARN.unwrap(resourceARN): java.lang.String)
      .optionallyWith(
        roleARN.map(value => RoleARN.unwrap(value): java.lang.String)
      )(_.roleARN)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription
      .wrap(buildAwsValue())
}
object KinesisStreamsOutputDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.KinesisStreamsOutputDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription =
      zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription(
        resourceARN,
        roleARN.map(value => value)
      )
    def resourceARN: ResourceARN
    def roleARN: Optional[RoleARN]
    def getResourceARN: ZIO[Any, Nothing, ResourceARN] =
      ZIO.succeed(resourceARN)
    def getRoleARN: ZIO[Any, AwsError, RoleARN] =
      AwsError.unwrapOptionField("roleARN", roleARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.KinesisStreamsOutputDescription
  ) extends zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription.ReadOnly {
    override val resourceARN: ResourceARN =
      zio.aws.kinesisanalyticsv2.model.primitives
        .ResourceARN(impl.resourceARN())
    override val roleARN: Optional[RoleARN] = zio.aws.core.internal
      .optionalFromNullable(impl.roleARN())
      .map(value => zio.aws.kinesisanalyticsv2.model.primitives.RoleARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.KinesisStreamsOutputDescription
  ): zio.aws.kinesisanalyticsv2.model.KinesisStreamsOutputDescription.ReadOnly =
    new Wrapper(impl)
}
